<?xml version="1.0" encoding="UTF-8"?>
<!--
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
  this work for additional information regarding copyright ownership.
  The ASF licenses this file to You under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with
  the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
-->
<!-- $Id$ -->
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ldn="http://www.lotus.com/dxl" 
xmlns:fo="http://www.w3.org/1999/XSL/Format" 
xmlns:pdf="http://xmlgraphics.apache.org/fop/extensions/pdf" exclude-result-prefixes="fo">
  <xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="yes"/>
  <xsl:param name="versionParam" select="'1.0'"/>
  <xsl:param name="body.font.family">Arial</xsl:param>
	
	<!-- ================= -->
  	<!-- omit other nodes  -->
  	<!-- ================= -->

	<xsl:template match="ldn:document/*[name()!='item']"/>
	<!-- ========================= -->
	<!-- root element: document    -->
	<!-- ========================= -->
	<xsl:template match="ldn:document">
		<fo:root font-family="Arial" font-size="8pt">
			<fo:layout-master-set>
				<fo:simple-page-master
					master-name="A4" 
					page-height="297mm" 
					page-width="210mm" 
					margin-top="10mm" 
					margin-bottom="10mm" 
					margin-left="10mm" 
					margin-right="10mm">
					<fo:region-body/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<fo:declarations>
				<xsl:apply-templates select="//ldn:file" /> 								
			</fo:declarations>
			<fo:page-sequence master-reference="A4">
				<fo:flow flow-name="xsl-region-body">
					<xsl:apply-templates select="ldn:item"/>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	
	</xsl:template>

	<!-- ========================= -->
	<!-- child element: item       -->
	<!-- ========================= -->
	<xsl:template match="ldn:item">
	<xsl:variable name="fname" select="ldn:object/ldn:file/@name"/>
	<xsl:variable name="fdata" select="ldn:object/ldn:file/ldn:filedata/text()"/>
	  
	<xsl:choose>
		<xsl:when test="./node()[name()='richtext']">
			<xsl:apply-templates match="ldn:richtext"/>
		</xsl:when>
		<xsl:otherwise></xsl:otherwise>
	</xsl:choose>
	</xsl:template>
  
	<!-- ============================= -->
	<!-- child element: item/richtext  -->
	<!-- ============================= -->
	<xsl:template match="ldn:richtext">
	      <xsl:apply-templates match="ldn:par"/>		  
	</xsl:template>

	<!-- ============================= -->
	<!-- child element: table          -->
	<!-- ============================= -->
	<xsl:template match="ldn:table" >
		<xsl:variable name="borderwidth" select="translate(translate(@htmlstyle,'border: ', ''), ';', '' )" />	
		<xsl:variable name="cellbordercolor" select="@cellbordercolor" />
		<xsl:variable name="refwidth" select="@refwidth" />
		<xsl:variable name="bordertype"></xsl:variable>
			
		<fo:table border-collapse="collapse" table-layout="fixed">
			<xsl:attribute name="width">
				<xsl:value-of select="@refwidth"/>
			</xsl:attribute>			
			<xsl:apply-templates select="ldn:tablecolumn" />
			<fo:table-body end-indent="0in">
				<xsl:apply-templates select="ldn:tablerow" />
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<!-- ============================= -->
	<!-- child element: tablecolumn	   -->
	<!-- ============================= -->
	<xsl:template match="ldn:tablecolumn">
		<xsl:variable name="tablewidth" select="@width" />	
		<fo:table-column >	
			<xsl:attribute name="column-width">				
				<xsl:value-of select="@width" />
			</xsl:attribute>				
		</fo:table-column>
	</xsl:template>

	<!-- ============================= -->
	<!-- child element: tablerow	   -->
	<!-- ============================= -->
	<xsl:template match="ldn:tablerow">
	    <fo:table-row>
	        <xsl:apply-templates select="ldn:tablecell" />
	    </fo:table-row>
	</xsl:template>

	<!-- ============================= -->
	<!-- child element: tablecell	   -->
	<!-- ============================= -->
	<xsl:template match="ldn:tablecell">
	    <fo:table-cell >
	    	
	    	<xsl:if test="../../@columnspacing">

	    		<xsl:attribute name="padding-start">
	    			<xsl:value-of select="../../@columnspacing"/>
	    		</xsl:attribute>    

	    		<xsl:attribute name="padding-end">
	    			<xsl:value-of select="../../@columnspacing"/>
	    		</xsl:attribute>

	    	</xsl:if>

	    	<xsl:if test="../../@rowspacing">

	    		<xsl:attribute name="padding-top">
					<xsl:value-of select="../../@rowspacing"/>
				</xsl:attribute>

	    		<xsl:attribute name="padding-bottom">
		    		<xsl:value-of select="../../@rowspacing"/>
		    	</xsl:attribute>
	    		
	    	</xsl:if>
	    	
	    	<xsl:attribute name="border-width">
				<xsl:choose>
					<xsl:when test="@borderwidth">
						<xsl:value-of select="@borderwidth" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>1px</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
	    	</xsl:attribute> 	
	    		
    		<xsl:if test="@bgcolor">
    			
    			<xsl:attribute name="background-color">
    				<xsl:value-of select="@bgcolor" />
    			</xsl:attribute>		
    			
    		</xsl:if>
  
	    	<xsl:attribute name="border">
	    		<xsl:choose>
	    			<xsl:when test="../../@cellbordercolor">
	    				<xsl:value-of select="concat('solid', ' ', ../../@cellbordercolor)" />
	    			</xsl:when>
	    			<xsl:otherwise>
	    				<xsl:text>solid black</xsl:text>
	    			</xsl:otherwise>
	    		</xsl:choose>
	    	</xsl:attribute>
	
	    	<xsl:if test="@rowspan!=''">
			
	    		<xsl:attribute name="number-rows-spanned">
					<xsl:value-of select="@rowspan" />
				</xsl:attribute>		
			
	    	</xsl:if>
			
	    	<xsl:if test="@columnspan!=''">
			
	    		<xsl:attribute name="number-columns-spanned">
					<xsl:value-of select="@columnspan" />
				</xsl:attribute>		
			
	    	</xsl:if><xsl:apply-templates/>
	    </fo:table-cell>
	</xsl:template>
	
	<!-- ============================= -->
	<!-- child element: tablecell	   -->
	<!-- ============================= -->
	<xsl:template match="ldn:par" name="ldn:par">
		<xsl:variable name="def" select="@def"></xsl:variable>
		<fo:block>
			<xsl:if test="//ldn:pardef[@id=$def]/@align">
				<xsl:attribute name="text-align">
					<xsl:value-of select="//ldn:pardef[@id=$def]/@align"/>
				</xsl:attribute>
			</xsl:if>
			
			<xsl:choose>
				
				<xsl:when test="string-length(*/text())=0">		
						&#160;
				</xsl:when>				
				<xsl:otherwise>						
					<xsl:if test="descendant::node()[2]/@size">
						<xsl:attribute name="font-size">
							<xsl:value-of select="descendant::node()[2]/@size" /> 
						</xsl:attribute>		
					</xsl:if>
					
					<xsl:if test="descendant::node()[2]/@color">		
						<xsl:attribute name="color">
							<xsl:value-of select="descendant::node()[2]/@color" />
						</xsl:attribute>		
					</xsl:if>
					
					<xsl:if test="contains(descendant::node()[2]/@style,'bold') != 0">
						<xsl:attribute name="font-weight">
							<xsl:value-of select="'bold'" />
						</xsl:attribute>		
					</xsl:if>
					
					<xsl:if test="contains(descendant::node()[2]/@style,'italic') != 0">
						<xsl:attribute name="font-style">
							<xsl:value-of select="'italic'" />
						</xsl:attribute>		
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>  
	
	<!-- ============================= -->
	<!-- child element: attache 	   -->
	<!-- ============================= -->
	<xsl:template match="ldn:file">
		<pdf:embedded-file>
			<xsl:attribute name="filename">
					<xsl:value-of select="@name" />
			</xsl:attribute>
			<xsl:attribute name="src">url('data:octet-stream;base64,<xsl:value-of select="translate( ldn:filedata/text(), '&#10;', '')"/>')</xsl:attribute>
		</pdf:embedded-file>		
	</xsl:template>
  
	<!-- ============================= -->
	<!-- child element: ref to attache -->
	<!-- ============================= -->
	<xsl:template match="ldn:attachmentref">
		<xsl:text>(см. файл </xsl:text>
		<fo:basic-link text-decoration="underline" color="blue">
				<xsl:attribute name="external-destination">
					<xsl:text>url(embedded-file:</xsl:text>
					<xsl:value-of select="@name" />
					<xsl:text>)</xsl:text>
				</xsl:attribute>
				<xsl:value-of select="@name"/>
		</fo:basic-link>
		<xsl:text>)</xsl:text>
	</xsl:template>    
	
	
	<!-- ============================= -->
	<!-- child element: embedded pics  -->
	<!-- ============================= -->
    <xsl:template match="ldn:picture/ldn:gif">
        <fo:external-graphic>
			<xsl:attribute name="content-height">scale-to-fit</xsl:attribute>
			<xsl:attribute name="scaling">non-uniform</xsl:attribute>
			<xsl:attribute name="height" >
				<xsl:value-of select="../@height" />
			</xsl:attribute>
			<xsl:attribute name="content-width" >
				<xsl:value-of select="../@width" />
			</xsl:attribute>
			<xsl:attribute name="src">url('data:image/jpeg;base64,<xsl:value-of select="."/>')</xsl:attribute>
		</fo:external-graphic>
    </xsl:template>

    <xsl:template match="ldn:picture/ldn:jpeg">
    	<fo:external-graphic>
			<xsl:attribute name="content-height">scale-to-fit</xsl:attribute>
			<xsl:attribute name="scaling">non-uniform</xsl:attribute>
			<xsl:attribute name="height" >
				<xsl:value-of select="../@height" />
			</xsl:attribute>
			<xsl:attribute name="content-width" >
				<xsl:value-of select="../@width" />
			</xsl:attribute>
			<xsl:attribute name="src">url('data:image/jpeg;base64,<xsl:value-of select="."/>')</xsl:attribute>
		</fo:external-graphic>
    </xsl:template>

	<xsl:template match="ldn:popup">
		<fo:block >
		</fo:block>
	</xsl:template>  
	
	<xsl:template match="ldn:break">
		<fo:block >
		</fo:block>
	</xsl:template>  
	
	<xsl:template match="ldn:compositedata">
		<fo:block >
		</fo:block>
	</xsl:template>  

</xsl:stylesheet>
